@@ -1,7 +1,5 @@
 #ifndef	MwGcs_h
 
-#ifdef	__STDC__
-
 extern	GC	AllocFgGC( Widget w, Pixel fg, Font font) ;
 extern	GC	AllocBackgroundGC( Widget w, Font font) ;
 extern	GC	AllocGreyGC( Widget w, Pixel fg, Font, int, int ) ;
@@ -12,21 +10,7 @@ extern	Pixel	AllocShadowPixel(Widget, int scale) ;
 extern	Pixmap	GetGrey50(Widget, Pixmap *);
 extern	Pixel	AllocGreyPixel(Widget, Pixel fg, Pixel bg, int contrast) ;
 extern	void	Draw3dBox(Widget w, int  x, int y, int wid, int hgt, int s,
-			GC topgc, GC botgc) ;
-
-#else
-
-extern	GC	AllocFgGC() ;
-extern	GC	AllocBackgroundGC() ;
-extern	GC	AllocGreyGC() ;
-extern	GC	AllocTopShadowGC() ;
-extern	GC	AllocBotShadowGC() ;
-extern	GC	AllocArmGC() ;
-extern	Pixel	AllocShadowPixel() ;
-extern	Pixel	AllocGreyPixel() ;
-extern	void	Draw3dBox() ;
-
-#endif
+			GC topgc, GC botgc, GC tophalf, GC bothalf) ;
 
 #define	MwGcs_h
 #endif
